==> protobuf-3.11.4-1-src.tar.bz2: osgeo4w/package.sh <==
#!/bin/bash

set -e

P=protobuf
V=3.11.4
B=1
MAINTAINER=JuergenFischer

cat() { /bin/cat "$@"; }
tar() { /bin/tar "$@"; }
rm() { /bin/rm "$@"; }
diff() { /bin/diff "$@"; }
mktemp() { /bin/mktemp "$@"; }
sed() { /bin/sed "$@"; }
mkdir() { /bin/mkdir "$@"; }

fetchenv() {
        local IFS
        IFS=
        local batch=$1
        shift

        if ! [ -f "$batch" ]; then
                echo "$batch not found"
                return 1
        fi

        srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
        dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
        diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
        envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
        cmd /c set >$srcenv
        cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
        cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
        s/\\\\/\\//g;
        s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
        s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
        diff -u $srcenv $dstenv | sed -f $envdiff >$diffenv
        . $diffenv
        PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
        rm -f $srcenv $dstenv $diffenv $envdiff
}

if ! [ -d "$OSGEO4W_REP" ]; then
	echo OSGEO4W_REP not set
	exit 1
fi

cd ..
[ -d protobuf ] || git clone -b v$V https://github.com/protocolbuffers/protobuf.git
cd protobuf
git submodule update --init --recursive

cd cmake

for ARCH in x86 x86_64; do
	export ARCH

	(
		case "$ARCH" in
		x86)
			export OSGEO4W_ROOT=/c/OSGeo4W
			export VCARCH=x86
			;;

		x86_64)
			export OSGEO4W_ROOT=/c/OSGeo4W64
			export VCARCH=x64
			;;

		*)
			echo invalid arch
			exit 1
			;;

		esac

		export R=$OSGEO4W_REP/$ARCH/release/$P
		mkdir -p $R

		cat <<EOF >$R/setup.hint
sdesc: "Protocol Buffers - Google's data interchange format"
ldesc: "Protocol Buffers - Google's data interchange format"
category: Libs
requires: msvcrt2015
EOF


		fetchenv "$OSGEO4W_ROOT/bin/o4w_env.bat"
		fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" $VCARCH
		export PATH="/c/Program Files (x86)/Microsoft Visual Studio 14.0/Common7/IDE:/c/Program Files/CMake/bin:$PATH:/bin"

		export BUILDCONF=RelWithDebInfo
		mkdir -p ../../osgeo4w/build-$ARCH ../../osgeo4w/install-$ARCH
		cd ../../osgeo4w/build-$ARCH

		cmake -G Ninja \
			-DCMAKE_BUILD_TYPE=$BUILDCONF \
			-DCMAKE_INSTALL_PREFIX=../install-$ARCH \
			../../protobuf/cmake

		cmake --build . --config $BUILDCONF
		cmake --build . --target install --config $BUILDCONF

		cd ../../osgeo4w

		/bin/tar -C install-$ARCH -cjf $R/$P-$V-$B.tar.bz2 bin  cmake  include  lib
		/bin/tar -C .. -cjf $R/$P-$V-$B-src.tar.bz2 osgeo4w/package.sh 
	)
done

date

==> protobuf-3.11.4-2-src.tar.bz2: osgeo4w/package.sh <==
#!/bin/bash

set -e

P=protobuf
V=3.11.4
B=2
MAINTAINER=JuergenFischer

cat() { /bin/cat "$@"; }
tar() { /bin/tar "$@"; }
rm() { /bin/rm "$@"; }
diff() { /bin/diff "$@"; }
mktemp() { /bin/mktemp "$@"; }
sed() { /bin/sed "$@"; }
mkdir() { /bin/mkdir "$@"; }

fetchenv() {
        local IFS
        IFS=
        local batch=$1
        shift

        if ! [ -f "$batch" ]; then
                echo "$batch not found"
                return 1
        fi

        srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
        dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
        diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
        envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
        cmd /c set >$srcenv
        cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
        cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
        s/\\\\/\\//g;
        s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
        s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
        diff -u $srcenv $dstenv | sed -f $envdiff >$diffenv
        . $diffenv
        PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
        rm -f $srcenv $dstenv $diffenv $envdiff
}

if ! [ -d "$OSGEO4W_REP" ]; then
	echo OSGEO4W_REP not set
	exit 1
fi

cd ..
[ -d protobuf ] || git clone -b v$V https://github.com/protocolbuffers/protobuf.git
cd protobuf
git submodule update --init --recursive

cd cmake

for ARCH in x86 x86_64; do
	export ARCH

	(
		case "$ARCH" in
		x86)
			export OSGEO4W_ROOT=/c/OSGeo4W
			export VCARCH=x86
			;;

		x86_64)
			export OSGEO4W_ROOT=/c/OSGeo4W64
			export VCARCH=x64
			;;

		*)
			echo invalid arch
			exit 1
			;;

		esac

		export R=$OSGEO4W_REP/$ARCH/release/$P
		mkdir -p $R/$P-devel

		cat <<EOF >$R/setup.hint
sdesc: "Protocol Buffers - Google's data interchange format"
ldesc: "Protocol Buffers - Google's data interchange format"
category: Libs
requires: msvcrt2015 zlib
EOF

		cat <<EOF >$R/$P-devel/setup.hint
sdesc: "Protocol Buffers - Google's data interchange format (development)"
ldesc: "Protocol Buffers - Google's data interchange format (development)"
category: Libs
requires: protobuf
external-source: $P
EOF


		fetchenv "$OSGEO4W_ROOT/bin/o4w_env.bat"
		fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" $VCARCH
		export PATH="/c/Program Files (x86)/Microsoft Visual Studio 14.0/Common7/IDE:/c/Program Files/CMake/bin:$PATH:/bin"

		export BUILDCONF=RelWithDebInfo
		mkdir -p ../../osgeo4w/build-$ARCH ../../osgeo4w/install-$ARCH
		cd ../../osgeo4w/build-$ARCH

		cmake -G Ninja \
			-DCMAKE_BUILD_TYPE=$BUILDCONF \
			-DCMAKE_INSTALL_PREFIX=../install-$ARCH \
			-Dprotobuf_BUILD_SHARED_LIBS=ON \
			../../protobuf/cmake

		cmake --build . --config $BUILDCONF
		cmake --build . --target install --config $BUILDCONF

		cd ../../osgeo4w/install-$ARCH

		/bin/tar -cjf $R/$P-devel/$P-devel-$V-$B.tar.bz2 bin/*.exe cmake include lib
		/bin/tar -cjf $R/$P-$V-$B.tar.bz2 bin/*.dll
		/bin/tar -C ../.. -cjf $R/$P-$V-$B-src.tar.bz2 osgeo4w/package.sh 
	)
done

date
